致命魔术 (豆瓣)
Description: 致命魔术电影简介和剧情介绍,致命魔术影评、图片、预告片、影讯、论坛、在线购票
Keywords: 致命魔术,The Prestige,致命魔术影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.79豆瓣电影Top250

# 致命魔术 The Prestige (2006)

导演: 克里斯托弗·诺兰
编剧: 乔纳森·诺兰 / 克里斯托弗·诺兰 / 克里斯托弗·普瑞丝特
主演: 休·杰克曼 / 克里斯蒂安·贝尔 / 迈克尔·凯恩 / 丽贝卡·豪尔 / 斯嘉丽·约翰逊 / 大卫·鲍伊 / 安迪·瑟金斯 / 派珀·佩拉博 / 萨曼塔·马霍林 / 丹尼尔·戴维斯 / 吉姆·皮多克 / 克里斯托弗·尼姆 / 马克·瑞安 / 罗杰·里斯 / 杰米·哈里斯 / 罗恩·帕金斯 / 瑞奇·杰 / 安东尼·德·马克 / 冀朝理
类型: 剧情 / 悬疑 / 惊悚
制片国家/地区: 英国 / 美国
语言: 英语
上映日期: 2006-10-17(罗马电影节) / 2006-10-20(美国)
片长: 130分钟
又名: 死亡魔法(港) / 顶尖对决(台) / 魔高一丈 / 魔道争锋
IMDb: tt0482571
豆瓣评分
引用
8.9
816432人评价
5星
54.2%
4星
37.3%
3星
7.8%
2星
0.6%
1星
0.2%
好于 99% 悬疑片
好于 98% 剧情片
想看 看过
评价:
推荐

## 致命魔术的剧情简介 · · · · · ·

19世纪末，人们对科学文明还不是认识得太过清楚，于是，安吉尔（休•杰克曼Hugh Jackman饰）和伯登（克里斯蒂安•贝尔Christian Bale饰）的魔术，成为了伦敦城内的神奇人物。安吉尔出身贵族，魔术手段华丽丰富，是富人圈子里的表演常客。而伯登即使出身平平，争强好胜的心智和充满创造力的魔术技巧，却也令他有了名气。两人自小本是要好的伙伴，然而，现在魔术界二人各有领地，并且都有野心想成为音乐大厅里的顶级魔术师，一番明争暗斗如箭在弦上。
伯登掌握了精彩的分身术，叫座又叫好。而安吉尔见情势不妙，搬来科学家助阵——他发明的交流电有无穷魔力，保证让观众目瞪口呆。二人出招接招，一来一往，争斗在剧烈升级，友谊和道德都被抛诸脑后，一场血案在悄悄酝酿。 ©豆瓣

## 致命魔术的演职员 · · · · · · ( 全部 29 )

- 克里斯托弗·诺兰 导演
- 休·杰克曼 饰 罗伯特·安吉尔 Robert Angier
- 克里斯蒂安·贝尔 饰 阿尔佛雷德·伯登 Alfred Borden
- 迈克尔·凯恩 饰 卡特 Cutter
- 丽贝卡·豪尔 饰 莎拉 Sarah
- 斯嘉丽·约翰逊 饰 奥莉维亚 Olivia Wenscombe

## 致命魔术的视频和图片 · · · · · · ( 预告片1 | 视频评论1 · 添加 | 图片1040 · 添加 )

## 致命魔术的获奖情况 · · · · · · ( 全部 )

- 第79届奥斯卡金像奖
- 最佳摄影(提名)
- 沃利·菲斯特

- 第79届奥斯卡金像奖
- 最佳艺术指导(提名)
- 内森·克劳利 / 朱莉·欧契萍妮

## 喜欢这部电影的人也喜欢 · · · · · ·

  记忆碎片

  禁闭岛

  盗梦空间

  蝴蝶效应

  看不见的客人

  控方证人

  穆赫兰道

  源代码

  致命ID

  利刃出鞘

我要写短评

## 致命魔术的短评 · · · · · · ( 全部 160228 条 )

热门 / 最新 / 好友

### 7064 有用 艾小柯 看过 2006-10-29 11:33:52

一个与同胞兄弟轮流上台享受欢呼与掌声，一个自我牺牲自我毁灭让复制品延续艺术生命。人性泯灭在狂热之中。

### 15218 有用 伊宜以忆 看过 2009-08-07 00:23:23

孪生蝙蝠侠大战克隆金刚狼

### 3009 有用 私享史 看过 2011-02-05 19:35:42

本片最大的看点其实是用Angier和Borden的幻术竞争来影射历史上Edison和Tesla的直流电与交流电之争。《记忆碎片》、《致命魔术》和《盗梦空间》基本上一个套路嘛。如果Nolan拍片子总是用这种捣蒜的方式讲故事的话，看多了真觉得没啥意思了。

### 13751 有用 水牧山 看过 2009-01-05 21:36:15

他选择了和他妻子一样的死法。100次。

### 2757 有用 束 看过 2009-12-18 02:55:55

这个片子有两个败点，其一：模式天才的胞弟出现太过唐突，显得有些老套；其二：用科幻成分作为支点，略显编剧底气不足。不过整体看来，属于上乘之作。

> 更多短评 160228条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 致命魔术的影评 · · · · · · ( 全部 1889 条 )

热门 / 最新 / 好友
梅斯布 2007-01-28 00:40:23

## 最伟大的魔术

《致命魔术》中最伟大的魔术师，显然不是Angier或者Borden，而是导演克里斯托弗·诺兰。 迄今为止，克里斯托弗·诺兰的电影都重复着相同的母题：复仇，这种复仇又往往与偏执、孤独、异于常人，等特性相联系。正如《失忆》中患有短期记忆丧失的主人公的复仇，《失眠》中患有失眠... (展开)
7205 462 782回应 收起
思考的猫 2007-03-02 23:36:47

## 闲谈《致命魔术》背后的电学斗争

美国电影《致命魔术》自从上映以来，称不上好评如潮，也是叫好连连，这里不再详谈该片了，只是从个人爱好角度谈谈该片背后的电学斗争背景，权当好玩。 应该说，本片一个意外影响便是让特斯拉（Tesla）这一电学天才重新浮出水面，他绝对是一个天才人物，来自塞尔维亚，童... (展开)
3567 226 305回应 收起
木卫二 2007-02-07 10:20:01

## 诺兰：我用科幻说服你

Spoiler Alert！（以下内容严重剧情泄露，没看过的就不要往下瞄了！） 1.Borden绝对是孪生兄弟，对此我深信不疑。影片可以找到的伏笔不是一处两处，不说一眼看穿中国老人魔术的那场，从看到鸟儿死去大哭的小孩到开门后的瞬间移动效果，Borden日记里透露的找Tesla不过是个骗局... (展开)
2861 200 492回应 收起
彭毅 2007-04-02 22:26:12

## 影片伏笔大揭露+疑问

这篇影评可能有剧透

这部片子没有辜负这个片名，剧情复杂，导演切换来切换去的拍摄手法，也像极了一部魔术。整部片子处处是伏笔，处处是妙招，刚开始让你看着一头雾水，但是随着影片时间的发展，一个一个悬念开始揭露，你的思路也开始慢慢清晰。然而，最大悬念你仍然无法想到，知道影片最后一刻，... (展开)
1751 172 519回应 收起
江声走 2007-02-10 17:14:56

## 我们每天杀死我们

我想起我中学时代的读过的维多利亚时代晚期一些通俗小说，像福尔摩斯或者凡尔纳的一些作品，在这些工业革命之后的小说里，可以看到许多奇形怪状的机器，因为那时的人们迷信机器就像今天的人们迷信知识；也可以看到和机器对应的许多阴暗的人群以及人群之间的怨愤，我不知是人类... (展开)
876 63 72回应 收起
绝版青春 2010-07-06 13:25:29

## 致命魔术——孪生蝙蝠侠大战克隆金刚狼

这篇影评可能有剧透

之所以副标题叫这个名字，是因为剧中的两大男主角一个扮演过《蝙蝠侠前传：黑暗骑士》中的蝙蝠侠，另一个扮演过《X战警》中的金刚狼，在本片中，这两位将展开究其一生的明争暗斗。 　　看了三遍《致命魔术》，就是想把它的每一个细节都完全理解、揣摩透。其实它比本片导演... (展开)
903 18 114回应 收起
火龙果不耐受者 2008-11-27 20:17:39

## 一切都是假象

故事发生在19世纪末的英国，Angier和Borden是两位魔术师，学徒时期曾是朋友，不想一次魔术事故中因为Borden的失误，导致Angier的妻子Julia溺水而死，从此两人结下仇并分道扬镳。之后Borden雇用了机械师Fallon自立门户，第一次表演抓子弹时，乔装打扮的Angier在枪上做了手脚，企... (展开)
695 56 90回应 收起
一支煤 2011-03-20 19:51:24

## borden为什么可以这样理直气壮？

这篇影评可能有剧透

我始终没搞懂为什么borden害死人家老婆还可以这么理直气壮?混若无事地对对手无情打击赶尽杀绝。最奇怪的是导演似乎也觉得这不是什么大事情，搞到最后他变成了复仇天使，安吉尔倒像是个机关算尽罪有应得的小人？我实在不明白这是为什么。无论怎么算，borden也要比安吉尔邪恶得多... (展开)
757 160 436回应 收起
刘康康 2011-09-16 18:13:50

## 来自客体的致命凝视

就如同希区柯克毫无疑问读过弗洛伊德的论文那样，诺兰也肯定读过拉康的论文。如果他们两人的电影都是在无意识地实践这些理论，那么他们就更伟大了。可以确定地说，克里斯托弗·诺兰的价值还远未被发掘出来，他的电影在将来必然是电影理论家的宠儿，如同今天那些理论家着迷地分... (展开)
378 24 43回应 收起
In Utero 2013-01-05 03:47:31

## 浅谈电影中出现的中国魔术师 Chung Ling Soo “程连苏”。

电影中引用了很多真实存在的人物。例如极富盛名的爱迪生 ，还有影片中另外一个富有神秘色彩的人物 Tesla 。对观众来说，似乎增加了一些更能让我们融入进去的真实性 。而另一个此片中的中国魔术师 程连苏的出现其实也是一个真实存在的人物，不过真实的历史事实上，他并... (展开)
281 10 23回应 收起

> 更多影评 1889篇

添加新讨论

## 讨论区 · · · · · ·

最后在监狱里Fallon和Borden是怎么互换的啊 我看漏... | 来自里欧里欧 | 1 回应 | 2022-11-22 01:11:36
很想看懂，但全程脸盲(*꒦ິ⌓꒦ີ) | 来自Melte. | 18 回应 | 2022-11-21 23:20:45
双胞胎在开始研究瞬移魔术之前为什么要假装一个人 | 来自板蓝根 | 1 回应 | 2022-11-20 21:21:32
为什么笑到最后的是伯登！！ | 来自Ian | 57 回应 | 2022-11-18 22:39:51
我不喜欢 | 来自夏木树花 | 9 回应 | 2022-11-18 22:37:03

> 去这部影片的讨论区（全部687条）

## 关于《致命魔术》的问题 · · · · · · ( 全部117个 )

- 有点乱，谁来帮我理理这些问题？ 20人回答
- 两个问题两个问题？ 11人回答

> 全部117个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 优酷视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【意外结局】 (影志)
- 意外结局+高智商 (鸟人与鱼)
- 曾经关于时空的豆列 (L.L)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)

## 谁在看这部电影 · · · · · ·

- 大橘大利🍊
  刚刚 想看
- ༡༥
  1分钟前 看过
- 落幕曲
  4分钟前 看过

1150755人看过 / 309105人想看

订阅致命魔术的评论:
feed: rss 2.0